@@ -2,7 +2,6 @@ package Imgur::API::Endpoint;
 
 use strict;
 
-use Imgur::API::Endpoint::Account;
 use Imgur::API::Endpoint::Account;
 use Imgur::API::Endpoint::Album;
 use Imgur::API::Endpoint::Comment;
@@ -13,6 +12,8 @@ use Imgur::API::Endpoint::Image;
 use Imgur::API::Endpoint::Memegen;
 use Imgur::API::Endpoint::Notification;
 use Imgur::API::Endpoint::Topic;
+use Imgur::API::Endpoint::Misc;
+use Imgur::API::Endpoint::OAuth;
 
 use Mouse;
 use Data::Dumper;
@@ -41,9 +42,9 @@ sub path {
 		}
 	}
 	if (scalar(@parts)) {
-		return join("/",$main,join("/",@parts));
+		return "https://api.imgur.com/".join("/",$main,join("/",@parts));
 	} else {
-		return $main;
+		return "https://api.imgur.com/$main";
 	}
 }
 
