@@ -1,3 +1,4 @@
+#!/usr/bin/env perl
 
 use JSON::XS;
 use Template;
@@ -10,7 +11,7 @@ my $tt = Template->new();
 foreach my $endpoint (keys %$data) {
 	say $endpoint;
 	my $stash = {name=>$endpoint,methods=>$data->{$endpoint}};
-	process_template("templates/class_template.tt","lib/Imgur/API/Endpoint/$endpoint.pm",$stash);
+	#process_template("templates/class_template.tt","lib/Imgur/API/Endpoint/$endpoint.pm",$stash);
 	process_template("templates/pod_template.tt","lib/Imgur/API/Endpoint/$endpoint.pod",$stash);
 }
 
